[][src]Module libsystemd_sys::id128

Structs

sd_id128_t

Note: this is marked Copy because the libsystemd apis pass it by value without implying an ownership transfer.

Constants

SD_ID128_STRING_MAX

Functions

sd_id128_from_string
sd_id128_get_boot
sd_id128_get_machine
sd_id128_randomize
sd_id128_to_string